# History of changes

## Version 1.0.1 (23/12/16)

* Always pass exceptions to the client.
* Replace print statements with logging for the exceptions.

## Version 1.0.0 (23/12/16)

* First working release.